Module debug_util

Module debug_util 

Debug helpers to inspect lookup witnesses.

They recompute every lookup tuple from the raw traces and assert that the resulting multiset is balanced (total multiplicity 0). Any mismatch will be reported with its location.

Structs

LookupDebugInstance
All inputs required to replay lookup evaluations for one AIR instance.

Functions

check_lookups
Recompute all lookup tuples/multiplicities from the traces and assert that every lookup represents a balanced multiset equality.