pub struct VerifierConstraintFolderWithLookups<'a, SC: StarkGenericConfig> {
pub inner: VerifierConstraintFolder<'a, SC>,
pub permutation: ViewPair<'a, SC::Challenge>,
pub permutation_challenges: &'a [SC::Challenge],
pub permutation_values: &'a [SC::Challenge],
}Fields
inner: VerifierConstraintFolder<'a, SC>permutation: ViewPair<'a, SC::Challenge>permutation_challenges: &'a [SC::Challenge]permutation_values: &'a [SC::Challenge]Trait Implementations
Sourceimpl<'a, SC: StarkGenericConfig> AirBuilder for VerifierConstraintFolderWithLookups<'a, SC>
impl<'a, SC: StarkGenericConfig> AirBuilder for VerifierConstraintFolderWithLookups<'a, SC>
Sourcetype F = <<<SC as StarkGenericConfig>::Pcs as Pcs<<SC as StarkGenericConfig>::Challenge, <SC as StarkGenericConfig>::Challenger>>::Domain as PolynomialSpace>::Val
type F = <<<SC as StarkGenericConfig>::Pcs as Pcs<<SC as StarkGenericConfig>::Challenge, <SC as StarkGenericConfig>::Challenger>>::Domain as PolynomialSpace>::Val
Underlying field type. Read more
Sourcetype Expr = <SC as StarkGenericConfig>::Challenge
type Expr = <SC as StarkGenericConfig>::Challenge
Serves as the output type for an AIR constraint evaluation.
Sourcetype Var = <SC as StarkGenericConfig>::Challenge
type Var = <SC as StarkGenericConfig>::Challenge
The type of the variable appearing in the trace matrix. Read more
Sourcetype PublicVar = <<<SC as StarkGenericConfig>::Pcs as Pcs<<SC as StarkGenericConfig>::Challenge, <SC as StarkGenericConfig>::Challenger>>::Domain as PolynomialSpace>::Val
type PublicVar = <<<SC as StarkGenericConfig>::Pcs as Pcs<<SC as StarkGenericConfig>::Challenge, <SC as StarkGenericConfig>::Challenger>>::Domain as PolynomialSpace>::Val
Variable type for public values.
Sourcetype PreprocessedWindow = RowWindow<'a, <SC as StarkGenericConfig>::Challenge>
type PreprocessedWindow = RowWindow<'a, <SC as StarkGenericConfig>::Challenge>
Two-row window over the preprocessed trace columns.
Sourcetype MainWindow = RowWindow<'a, <SC as StarkGenericConfig>::Challenge>
type MainWindow = RowWindow<'a, <SC as StarkGenericConfig>::Challenge>
Two-row window over the main trace columns.
Sourcefn main(&self) -> Self::MainWindow
fn main(&self) -> Self::MainWindow
Return the current and next row slices of the main (primary) trace.
Sourcefn preprocessed(&self) -> &Self::PreprocessedWindow
fn preprocessed(&self) -> &Self::PreprocessedWindow
Return the preprocessed registers as a two-row window. Read more
Sourcefn public_values(&self) -> &[Self::PublicVar]
fn public_values(&self) -> &[Self::PublicVar]
Public input values available during constraint evaluation. Read more
Sourcefn is_first_row(&self) -> Self::Expr
fn is_first_row(&self) -> Self::Expr
Expression evaluating to a non-zero value only on the first row.
Sourcefn is_last_row(&self) -> Self::Expr
fn is_last_row(&self) -> Self::Expr
Expression evaluating to a non-zero value only on the last row.
Sourcefn is_transition_window(&self, size: usize) -> Self::Expr
fn is_transition_window(&self, size: usize) -> Self::Expr
Expression evaluating to zero only on the last
size - 1 rows. Read moreSourcefn assert_zero<I: Into<Self::Expr>>(&mut self, x: I)
fn assert_zero<I: Into<Self::Expr>>(&mut self, x: I)
Assert that the given element is zero. Read more
Sourcefn assert_zeros<const N: usize, I: Into<Self::Expr>>(&mut self, array: [I; N])
fn assert_zeros<const N: usize, I: Into<Self::Expr>>(&mut self, array: [I; N])
Assert that every element of a given array is 0. Read more
Sourcefn is_transition(&self) -> Self::Expr
fn is_transition(&self) -> Self::Expr
Expression evaluating to zero only on the last row.
Sourcefn when<I>(&mut self, condition: I) -> FilteredAirBuilder<'_, Self>
fn when<I>(&mut self, condition: I) -> FilteredAirBuilder<'_, Self>
Returns a sub-builder whose constraints are enforced only when
condition is nonzero.Sourcefn when_ne<I1, I2>(&mut self, x: I1, y: I2) -> FilteredAirBuilder<'_, Self>
fn when_ne<I1, I2>(&mut self, x: I1, y: I2) -> FilteredAirBuilder<'_, Self>
Returns a sub-builder whose constraints are enforced only when
x != y.Sourcefn when_first_row(&mut self) -> FilteredAirBuilder<'_, Self>
fn when_first_row(&mut self) -> FilteredAirBuilder<'_, Self>
Returns a sub-builder whose constraints are enforced only on the first row.
Sourcefn when_last_row(&mut self) -> FilteredAirBuilder<'_, Self>
fn when_last_row(&mut self) -> FilteredAirBuilder<'_, Self>
Returns a sub-builder whose constraints are enforced only on the last row.
Sourcefn when_transition(&mut self) -> FilteredAirBuilder<'_, Self>
fn when_transition(&mut self) -> FilteredAirBuilder<'_, Self>
Returns a sub-builder whose constraints are enforced on all rows except the last.
Sourcefn when_transition_window(
&mut self,
size: usize,
) -> FilteredAirBuilder<'_, Self>
fn when_transition_window( &mut self, size: usize, ) -> FilteredAirBuilder<'_, Self>
Like
when_transition, but requires a window of size rows.Sourcefn assert_bools<const N: usize, I>(&mut self, array: [I; N])
fn assert_bools<const N: usize, I>(&mut self, array: [I; N])
Assert that a given array consists of only boolean values.
Sourcefn assert_one<I>(&mut self, x: I)
fn assert_one<I>(&mut self, x: I)
Assert that
x element is equal to 1.Sourceimpl<SC: StarkGenericConfig> ExtensionBuilder for VerifierConstraintFolderWithLookups<'_, SC>
impl<SC: StarkGenericConfig> ExtensionBuilder for VerifierConstraintFolderWithLookups<'_, SC>
Sourcetype EF = <SC as StarkGenericConfig>::Challenge
type EF = <SC as StarkGenericConfig>::Challenge
Extension field type.
Sourcetype ExprEF = <SC as StarkGenericConfig>::Challenge
type ExprEF = <SC as StarkGenericConfig>::Challenge
Expression type over extension field elements.
Sourcetype VarEF = <SC as StarkGenericConfig>::Challenge
type VarEF = <SC as StarkGenericConfig>::Challenge
Variable type over extension field elements.
Sourcefn assert_zero_ext<I>(&mut self, x: I)
fn assert_zero_ext<I>(&mut self, x: I)
Assert that an extension field expression is zero.
Sourcefn assert_eq_ext<I1, I2>(&mut self, x: I1, y: I2)
fn assert_eq_ext<I1, I2>(&mut self, x: I1, y: I2)
Assert that two extension field expressions are equal.
Sourcefn assert_one_ext<I>(&mut self, x: I)
fn assert_one_ext<I>(&mut self, x: I)
Assert that an extension field expression is equal to one.
Sourceimpl<'a, SC: StarkGenericConfig> PermutationAirBuilder for VerifierConstraintFolderWithLookups<'a, SC>
impl<'a, SC: StarkGenericConfig> PermutationAirBuilder for VerifierConstraintFolderWithLookups<'a, SC>
Sourcetype RandomVar = <SC as StarkGenericConfig>::Challenge
type RandomVar = <SC as StarkGenericConfig>::Challenge
Randomness variable type used in permutation commitments.
Sourcetype MP = RowWindow<'a, <SC as StarkGenericConfig>::Challenge>
type MP = RowWindow<'a, <SC as StarkGenericConfig>::Challenge>
Two-row window over the permutation trace columns.
Sourcetype PermutationVar = <SC as StarkGenericConfig>::Challenge
type PermutationVar = <SC as StarkGenericConfig>::Challenge
Value type for expected cumulated values used in global lookup arguments.
Sourcefn permutation(&self) -> Self::MP
fn permutation(&self) -> Self::MP
Return the current and next row slices of the permutation trace.
Sourcefn permutation_randomness(&self) -> &[SC::Challenge]
fn permutation_randomness(&self) -> &[SC::Challenge]
Return the list of randomness values for permutation argument.
Sourcefn permutation_values(&self) -> &[SC::Challenge]
fn permutation_values(&self) -> &[SC::Challenge]
Return the expected cumulated values for global lookup arguments.