LogUpGadget

Struct LogUpGadget 

pub struct LogUpGadget;
Core LogUp gadget implementing lookup arguments via logarithmic derivatives.

The LogUp gadget transforms the multiplicative lookup constraint:

∏(α - a_i)^(m_i) = ∏(α - b_j)^(m'_j)

Into an equivalent additive constraint using logarithmic differentiation:

∑(m_i/(α - a_i)) = ∑(m'_j/(α - b_j))

This is implemented using a running sum auxiliary column s that accumulates:

s[i+1] = s[i] + ∑(m_a/(α - a)) - ∑(m_b/(α - b))

Note that we do not differentiate between a and b in the implementation: we simply have a list of elements with possibly negative multiplicities.

Constraints are defined as:

  • Initial Constraint: s[0] = 0
  • Transition Constraint: s[i+1] = s[i] + contribution[i]
  • Final Constraint: s[n-1] + contribution[n-1] = 0

Implementations

Source

impl LogUpGadget

pub const fn new() -> Self

Creates a new LogUp gadget instance.