pub struct Lookup<F: Field> {
pub kind: Kind,
pub element_exprs: Vec<Vec<SymbolicExpression<F>>>,
pub multiplicities_exprs: Vec<SymbolicExpression<F>>,
pub columns: Vec<usize>,
}Expand description
A structure that holds the lookup data necessary to generate lookup contexts. It is shared between the prover and the verifier.
Fields
kind: KindType of lookup: local or global
element_exprs: Vec<Vec<SymbolicExpression<F>>>Elements being read (consumed from the table). Each Vec<SymbolicExpression<F>>
actually represents a tuple of elements that are bundled together to make one lookup.
multiplicities_exprs: Vec<SymbolicExpression<F>>Multiplicities for the elements. Note that Lagrange selectors may not be normalized, and so cannot be used as proper filters in the multiplicities.
columns: Vec<usize>The column index in the permutation trace for this lookup’s running sum
Implementations
Sourceimpl<F: Field> Lookup<F>
impl<F: Field> Lookup<F>
Sourcepub const fn new(
kind: Kind,
element_exprs: Vec<Vec<SymbolicExpression<F>>>,
multiplicities_exprs: Vec<SymbolicExpression<F>>,
columns: Vec<usize>,
) -> Self
pub const fn new( kind: Kind, element_exprs: Vec<Vec<SymbolicExpression<F>>>, multiplicities_exprs: Vec<SymbolicExpression<F>>, columns: Vec<usize>, ) -> Self
Creates a new lookup with the specified column.
Arguments
elements- Elements from either the main execution trace or a lookup table.multiplicities- How many times eachelementshould appearcolumn- The column index in the permutation trace for this lookup