pub struct LookupData<F> {
pub name: String,
pub aux_idx: usize,
pub expected_cumulated: F,
}Expand description
Data required for global lookup arguments in a multi-STARK proof.
Fields
name: StringName of the global lookup interaction.
aux_idx: usizeIndex of the auxiliary column (if there are multiple auxiliary columns, this is the first one)
expected_cumulated: FExpected cumulated value for a global lookup argument.