pub type LookupInput<F> = (Vec<SymbolicExpression<F>>, SymbolicExpression<F>, Direction);Expand description
A type alias for a lookup input tuple.
The tuple contains:
- a vector of symbolic expressions representing the elements involved in the lookup,
- a symbolic expression representing the multiplicity of the lookup,
- a direction indicating whether the elements are being sent or received.
Example
use p3_lookup::{LookupInput, Direction};
use p3_air::SymbolicExpression;
let lookup_input: LookupInput<SymbolicExpression<F>> = (
vec![SymbolicExpression::Constant(F::ONE)],
SymbolicExpression::Constant(F::ONE),
Direction::Send
);